#
# spec file for package libwpe
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# When updating this, do so in baselibs.conf too
%define major_minor 1.0
%define sover 1_0-1

Name:           libwpe
Version:        1.14.1
Release:        1.3
Summary:        General-purpose library for the WPE-flavored port of WebKit
License:        BSD-2-Clause
URL:            https://github.com/WebPlatformForEmbedded/libwpe
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source99:       baselibs.conf

BuildRequires:  c++_compiler
BuildRequires:  meson >= 0.49
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(xkbcommon)

%description
General-purpose library developed for the WPE-flavored port of
WebKit.

%package     -n %{name}-%{sover}
Summary:        Shared library for %{name}

%description -n %{name}-%{sover}
General-purpose library developed for the WPE-flavored port of
WebKit.
This package contains the shared libary of libwpe.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries, build data, and
header files for developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n %{name}-%{sover}

%files -n %{name}-%{sover}
%license COPYING
%doc NEWS
%{_libdir}/%{name}-%{major_minor}.so.*

%files devel
%{_includedir}/wpe-%{major_minor}/
%{_libdir}/%{name}-%{major_minor}.so
%{_libdir}/pkgconfig/wpe-%{major_minor}.pc

%changelog
* Thu Aug 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.1:
  + Fix the build with older glibc C library versions.
* Tue Oct  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.0:
  + New API to provide input events to be treated by WebKit as
    gamepad inputs.
  + New API to configure the target refresh rate of view backends.
  + New API which allow clients to supply an alternative mechanism
    for spawning WebKit auxiliary processes.
  + New WPE_ENABLE_XKB build option, enabled by default, which can
    be used to avoid usage of libxkbcommon.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri Aug 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.3:
  + Fix the build when using Clang's libc++ or the Musl libc.
- Changes from version 1.12.2:
  + Fix the build when using CMake to configure it.
- Changes from version 1.12.1:
  + Fix pasteboard to use the generic interface by default.
  + Fix memory allocation to always abort execution on failure.
* Thu Nov 25 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.12.0:
  + New API to handle requests initiated by web content to
    (un)fullscreen web views.
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.10.1:
  - Fix the build with versions of Python older than 3.6
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.10.0:
  - New API to explicitly deinitialize an EGL renderer target, which allows
    implementors of the wpe_renderer_backend_egl_target_interface
  - build system improvements
* Thu Sep 17 2020 Michael Gorse <mgorse@suse.com>
- Update to version 1.8.0:
  + New build configuration system based on Meson. The existing
    CMake-based system is still maintained, and both produce the
    same outputs.
  + Hidden visibility is now used by default for symbols, and only
    those belonging to the public API are exported.
- Switch to meson.
* Thu Mar 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.0:
  + Added support for smooth 2D axis input events.
  + Ensure that only symbols marked with WPE_EXPORT are public.
  + Improved robustness of the CMake build system.
- Changes from version 1.5.90:
  + Added support for smooth 2D axis input events.
  + Improved robustness of the CMake build system.
* Sat Oct  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add baselibs.conf, build 32-bit support lib.
* Thu Oct  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.0.1:
  + Fix the version numbers to ensure 1.4.0 is used when building
    from tarballs.
- Drop no longer needed Group tag.
* Thu Sep 19 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.0:
  + New API to set the device scaling factor. Backends and WebKit
    embedders can use this to e.g. support HiDPI displays.
  + New API to to obtain the root accessibility object for a view
    backend.
  + API reference documentation can now be built with HotDoc.
    Descriptions for most functionality is still missing, though.
  + Fix build failure on systems where libxkbcommon has its headers
    installed in a non-standard location.
* Tue Sep 17 2019 Michael Gorse <mgorse@suse.com>
- Update to version 1.3.91:
  + Enabled compiler warnings.
  + Fix build failure on systems where libxkbcommon has its headers
    installed in a non-standard location.
  + Fix documentation build.
- Drop libwpe-fix-include-dir.patch: fixed upstream.
* Wed Jul 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE, version 1.3.1.
